# pymsoverview
A python implementation of msoverview, print basic information a measurement-set


## Usage:

Install

```bash
git clone https://github.com/peijin94/pymsoverview.git
python setup.py install
```

Data inspection:

```bash
# basic info
python -m pymsoverview -f xxxxx.MS
# more detailed info
python -m pymsoverview -f xxxxx.MS -v
```